/***************************************************************************
 *
 * alert_dialogue.c : GNOME Power Preferences
 *
 * Copyright (C) 2005 Richard Hughes, <richard@hughsie.com>
 *
 * Taken in part from:
 * - GNOME Tutorial, example 1
 * http://www.gnome.org/~newren/tutorials/developing-with-gnome/html/apd.html
 *
 * Licensed under the GNU GPL v2.  See COPYING.
 *
 **************************************************************************/

#include <stdio.h>
#include <stdlib.h>
#include <string.h>
#include <unistd.h>

#include <gtk/gtk.h>
#include <glade/glade.h>
#include <gconf/gconf-client.h>

#include "common.h"

static GladeXML *all_alert_widgets;
static char *text;
static char *signal;

static void
callback_check_changed (GtkWidget *widget, gpointer user_data)
{
	gboolean value;
	const char *name;
	GConfClient *client = gconf_client_get_default ();
	gchar *gconfpath;

	name = gtk_widget_get_name(widget);
	value = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (widget));	

	/*gconfpath = g_strconcat ("/apps/gnome-power/icons/", name + 6, NULL);
	gconf_client_set_bool (client, gconfpath, value, NULL);
	g_free (gconfpath);*/

	g_print ("%s (%s) = %i\n", name, signal, value);

}

int
main (int argc, char **argv)
{
	GtkWidget *widget = NULL;
	gtk_init (&argc, &argv);

	/* load the interface */
	all_alert_widgets = glade_xml_new (GPM_DATA "alert.glade", NULL, NULL);
	if (!all_alert_widgets) {
		g_print ("glade file failed to load, aborting\n");
		return 0;
	}

	/* Get the GconfClient, tell it we want to monitor /apps/gnome-power */
	GConfClient *client = gconf_client_get_default ();
	gconf_client_add_dir (client, "/apps/gnome-power", GCONF_CLIENT_PRELOAD_NONE, NULL);

	/* Get the main_window quit */
	widget = glade_xml_get_widget (all_alert_widgets, "window_alert");
	g_signal_connect (G_OBJECT (widget), "delete_event", G_CALLBACK (gtk_main_quit), NULL);

	/* Get the quit button */
	widget = glade_xml_get_widget (all_alert_widgets, "button_close");
	g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (gtk_main_quit), NULL);

	/* monitor check box */
	widget = glade_xml_get_widget (all_alert_widgets, "check_noshow");
	if (!widget) g_print ("failed to get check\n");
	g_signal_connect (G_OBJECT (widget), "clicked", G_CALLBACK (callback_check_changed), NULL);

	/* get environment variables */
	text = getenv ("GPM_ALERT_TEXT");
	if (!text)
		text = "Unknown. An error has occurred";
	signal = getenv ("GPM_ALERT_SIGNAL");
	if (!signal)
		signal = "Unknown";

	char *description_text;

	/* set the description text */
	widget = glade_xml_get_widget (all_alert_widgets, "label_description");
	description_text = g_strconcat ("The device '", text ,"' has a low battery.", NULL);
	gtk_label_set_text (GTK_LABEL (widget), description_text);
	g_free (description_text);

	/* start the event loop */
	gtk_main ();
	return EXIT_SUCCESS;
}
